ShimmerPro class
Use only ShimmerPro.sized, ShimmerPro.text or ShimmerPro.generated not use ShimmerPro.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ShimmerPro
Constructors
- ShimmerPro.generated({Key? key, int depth = 20, Duration duration = const Duration(seconds: 1), double? borderRadius = 10, Alignment? alignment = Alignment.center, ShimmerProLight? light = ShimmerProLight.darker, required Color scaffoldBackgroundColor, double? width, double? height, required Widget? child})
-
ShimmerPro.generated must use children widgets.
You can delegate
width;ShimmerPro.text generate text shimmer.durationanimation duration.borderRadiussized widget border radius.alignmentsized vidget alignment. Defoult Alignment.center.lightshimmer is lighter color or darker color.scaffoldBackgroundColormust be geven. ShimmerPro.text generate from this color.childmust be Column or Row for best seen. - ShimmerPro.sized({Key? key, int depth = 20, Duration duration = const Duration(seconds: 1), double? borderRadius = 10, Alignment? alignment = Alignment.center, ShimmerProLight? light = ShimmerProLight.darker, required Color scaffoldBackgroundColor, required double? height, required double? width})
-
ShimmerPro.sized must use sized widgets.
With using
widthandheight;ShimmerPro.sized generate sized shimmer.durationanimation duration.borderRadiussized widget border radius.alignmentsized vidget alignment. Defoult Alignment.center.lightshimmer is lighter color or darker color.scaffoldBackgroundColormust be geven. ShimmerPro.sized generate from this color. - ShimmerPro.text({Key? key, int depth = 20, Duration duration = const Duration(seconds: 1), int? maxLine = 3, double? textSize = 14, double? borderRadius = 10, Alignment? alignment = Alignment.center, ShimmerProLight? light = ShimmerProLight.darker, required Color scaffoldBackgroundColor, double? width})
-
ShimmerPro.text must use text widgets.
You can delegate
width;ShimmerPro.text generate text shimmer.durationanimation duration.borderRadiussized widget border radius.alignmentsized vidget alignment. Defoult Alignment.center.lightshimmer is lighter color or darker color.scaffoldBackgroundColormust be geven. ShimmerPro.text generate from this color.maxLineis defoult 3. ShimmerPro.text will be generated this count.textSizeis ShimmerPro.text's text size.Defoult 14.
Properties
- alignment ↔ Alignment?
-
getter/setter pair
- borderRadius ↔ double?
-
getter/setter pair
- child ↔ Widget?
-
getter/setter pair
- depth → int
-
final
- duration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ double?
-
getter/setter pair
- isGenerated ↔ bool
-
getter/setter pair
- isSized ↔ bool
-
getter/setter pair
- isText ↔ bool
-
getter/setter pair
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- light ↔ ShimmerProLight?
-
getter/setter pair
- maxLine ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaffoldBackgroundColor ↔ Color
-
getter/setter pair
- textSize ↔ double?
-
getter/setter pair
- width ↔ double?
-
getter/setter pair
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ShimmerPro> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited